package MyDB::Main;
use base qw/DBIx::Class::Schema/;
__PACKAGE__->load_classes();

1;
